==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/nl-NL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bevestig bulk verwijdering van assets',
    'bulk_restore'      => 'Bevestig bulk herstel van assets', 
  'bulk_delete_help'	=> 'Bekijk de assets voor bulkverwijdering hieronder. Eenmaal verwijderd, kunnen deze assets worden hersteld, maar ze zullen niet langer geassocieerd worden met gebruikers waaraan ze momenteel zijn toegewezen.',
  'bulk_restore_help'	=> 'Bekijk hieronder de items voor bulk herstel. Eenmaal hersteld, worden deze middelen niet meer gekoppeld aan gebruikers waaraan ze eerder waren toegewezen.',
  'bulk_delete_warn'	=> 'Je staat op het punt om :asset_count assets te verwijderen.',
  'bulk_restore_warn'	=> 'U staat op het punt om :asset_count asset te herstellen.',
    'bulk_update'		=> 'Meerdere activa bijwerken',
    'bulk_update_help'	=> 'Met dit formulier kun je meerdere assets tegelijk bijwerken. Vul alleen de velden in die je moet wijzigen. Alle lege velden blijven ongewijzigd. ',
    'bulk_update_warn'	=> 'Je staat op het punt om de eigenschappen van één bezitting te bewerken. Je staat op het punt om de eigenschappen van :asset_count bezittingen te bewerken.',
    'bulk_update_with_custom_field' => 'Let op: de assets hebben :asset_model_count verschillende soorten modellen.',
    'bulk_update_model_prefix' => 'Op modellen', 
    'bulk_update_custom_field_unique' => 'Dit is een uniek veld en kan niet in bulk worden bewerkt.',
    'checkedout_to'		=> 'Uitgecheckt aan',
    'checkout_date'		=> 'Uitgecheckt datum',
    'checkin_date'		=> 'Ingecheckt datum',
    'checkout_to'		=> 'Uitchecken aan',
    'cost'				=> 'Aankoopprijs',
    'create'			=> 'Asset aanmaken',
    'date'				=> 'Aankoopdatum',
    'depreciation'	    => 'Afschrijving',
    'depreciates_on'	=> 'Afschrijving op',
    'default_location'	=> 'Standaardlocatie',
    'default_location_phone' => 'Standaard Locatie Telefoon',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'Duur EOL',
    'expected_checkin'  => 'Verwachte incheck datum',
    'expires'			=> 'Vervalt op',
    'fully_depreciated'	=> 'Volledig afgeschreven',
    'help_checkout'		=> 'Als je dit asset onmiddellijk wilt toewijzen, selecteer dan "klaar om uit te geven" van de bovenstaande lijst. ',
    'mac_address'		=> 'MAC-adres',
    'manufacturer'		=> 'Fabrikant',
    'model'				=> 'Model',
    'months'			=> 'maanden',
    'name'				=> 'Asset naam',
    'notes'				=> 'Opmerkingen',
    'order'				=> 'Ordernummer',
    'qr'				=> 'QR-code',
    'requestable'		=> 'Gebruikers mogen dit asset aanvragen',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Selecteer status type',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Assettag',
    'update'			=> 'Asset update',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garantie vervalt',
    'years'				=> 'jaar',
    'asset_location' => 'Update Asset locatie',
    'asset_location_update_default_current' => 'Update standaard locatie EN huidige locatie',
    'asset_location_update_default' => 'Update alleen standaard locatie',
    'asset_location_update_actual' => 'Alleen actuele locatie bijwerken',
    'asset_not_deployable' => 'Deze Asset status is niet uitgeefbaar. Dit Asset kan niet uitgegeven worden.',
    'asset_deployable' => 'Deze status is uitgeefbaar. Dit Asset kan uitgegeven worden.',
    'processing_spinner' => 'Verwerken... (Dit kan enige tijd duren bij grote bestanden)',
    'optional_infos'  => 'Optionele informatie',
    'order_details'   => 'Bestelling Gerelateerde Informatie'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/nl-NL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bevestig bulk verwijdering van assets',
    'bulk_restore'      => 'Bevestig bulk herstel van assets', 
  'bulk_delete_help'	=> 'Bekijk de assets voor bulkverwijdering hieronder. Eenmaal verwijderd, kunnen deze assets worden hersteld, maar ze zullen niet langer geassocieerd worden met gebruikers waaraan ze momenteel zijn toegewezen.',
  'bulk_restore_help'	=> 'Bekijk hieronder de items voor bulk herstel. Eenmaal hersteld, worden deze middelen niet meer gekoppeld aan gebruikers waaraan ze eerder waren toegewezen.',
  'bulk_delete_warn'	=> 'Je staat op het punt om :asset_count assets te verwijderen.',
  'bulk_restore_warn'	=> 'U staat op het punt om :asset_count asset te herstellen.',
    'bulk_update'		=> 'Meerdere activa bijwerken',
    'bulk_update_help'	=> 'Met dit formulier kun je meerdere assets tegelijk bijwerken. Vul alleen de velden in die je moet wijzigen. Alle lege velden blijven ongewijzigd. ',
    'bulk_update_warn'	=> 'Je staat op het punt om de eigenschappen van één bezitting te bewerken. Je staat op het punt om de eigenschappen van :asset_count bezittingen te bewerken.',
    'bulk_update_with_custom_field' => 'Let op: de assets hebben :asset_model_count verschillende soorten modellen.',
    'bulk_update_model_prefix' => 'Op modellen', 
    'bulk_update_custom_field_unique' => 'Dit is een uniek veld en kan niet in bulk worden bewerkt.',
    'checkedout_to'		=> 'Uitgecheckt aan',
    'checkout_date'		=> 'Uitgecheckt datum',
    'checkin_date'		=> 'Ingecheckt datum',
    'checkout_to'		=> 'Uitchecken aan',
    'cost'				=> 'Aankoopprijs',
    'create'			=> 'Asset aanmaken',
    'date'				=> 'Aankoopdatum',
    'depreciation'	    => 'Afschrijving',
    'depreciates_on'	=> 'Afschrijving op',
    'default_location'	=> 'Standaardlocatie',
    'default_location_phone' => 'Standaard Locatie Telefoon',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'Duur EOL',
    'expected_checkin'  => 'Verwachte incheck datum',
    'expires'			=> 'Vervalt op',
    'fully_depreciated'	=> 'Volledig afgeschreven',
    'help_checkout'		=> 'Als je dit asset onmiddellijk wilt toewijzen, selecteer dan "klaar om uit te geven" van de bovenstaande lijst. ',
    'mac_address'		=> 'MAC-adres',
    'manufacturer'		=> 'Fabrikant',
    'model'				=> 'Model',
    'months'			=> 'maanden',
    'name'				=> 'Asset naam',
    'notes'				=> 'Opmerkingen',
    'order'				=> 'Ordernummer',
    'qr'				=> 'QR-code',
    'requestable'		=> 'Gebruikers mogen dit asset aanvragen',
    'redirect_to_all'   => 'Terug naar alle :type',
    'redirect_to_type'   => 'Ga naar :type',
    'redirect_to_checked_out_to'   => 'Ga naar uitcheckt naar',
    'select_statustype'	=> 'Selecteer status type',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Assettag',
    'update'			=> 'Asset update',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garantie vervalt',
    'years'				=> 'jaar',
    'asset_location' => 'Update Asset locatie',
    'asset_location_update_default_current' => 'Update standaard locatie EN huidige locatie',
    'asset_location_update_default' => 'Update alleen standaard locatie',
    'asset_location_update_actual' => 'Alleen actuele locatie bijwerken',
    'asset_not_deployable' => 'Deze Asset status is niet uitgeefbaar. Dit Asset kan niet uitgegeven worden.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Deze status is uitgeefbaar. Dit Asset kan uitgegeven worden.',
    'processing_spinner' => 'Verwerken... (Dit kan enige tijd duren bij grote bestanden)',
    'optional_infos'  => 'Optionele informatie',
    'order_details'   => 'Bestelling Gerelateerde Informatie'
];
